.. image:: images/zhinst_logo_sep_horiz_2019_1000.png
   :width: 400
   :target: https://www.zhinst.com

|

Zurich Instruments Labber driver |version| Documentation
=========================================================

The Zurich Instruments drivers for Labber (zhinst-labber) is a package that is
able to generate instrument drivers for devices produced by
`Zurich Instruments <https://www.zhinst.com>`_ for Labber.
`Labber <https://www.keysight.com/ch/de/products/software/application-sw/labber-software.html>`_
is a instrument control and lab automation software.

The drivers are based on `zhinst-toolkit <https://github.com/zhinst/zhinst-toolkit>`_,
a generic high level python driver for LabOne.

Get started with the :doc:`first_steps/installation` and then get
an overview with the :doc:`first_steps/quickstart` guide.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   first_steps/index
   features/index
   changelog/index
   license/index
   about/index



Index
=====

* :ref:`genindex`

